Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--plugins/org.eclipse.emf.cdo.common/src/org/eclipse/emf/cdo/spi/common/revision/InternalCDORevision.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/org.eclipse.emf.cdo.common/src/org/eclipse/emf/cdo/spi/common/revision/InternalCDORevision.java b/plugins/org.eclipse.emf.cdo.common/src/org/eclipse/emf/cdo/spi/common/revision/InternalCDORevision.java
index 9f03c7adfe..69166af395 100644
--- a/plugins/org.eclipse.emf.cdo.common/src/org/eclipse/emf/cdo/spi/common/revision/InternalCDORevision.java
+++ b/plugins/org.eclipse.emf.cdo.common/src/org/eclipse/emf/cdo/spi/common/revision/InternalCDORevision.java
@@ -84,11 +84,11 @@ public interface InternalCDORevision extends CDORevision, CDORevisionData, CDORe
public CDOList getList(EStructuralFeature feature);
/**
* @param size
* the size of a new list to be created if this revision has no list so far, or -1 to skip list creation and
* return <code>null</code> in this case.
*/
- public CDOList getList(EStructuralFeature feature, int size);
+ public CDOList getList(EStructuralFeature feature, int initialCapacity);
/**
* @since 3.0
@@ -84,11 +84,11 @@ public interface InternalCDORevision extends CDORevision, CDORevisionData, CDORe
public CDOList getList(EStructuralFeature feature);
/**
- * @param size
- * the size of a new list to be created if this revision has no list so far, or -1 to skip list creation and
- * return <code>null</code> in this case.
+ * @param initialCapacity
+ * the initialCapacity of a new list to be created if this revision has no list so far (its size will always
+ * be 0), or -1 to skip list creation and return <code>null</code> in this case.
*/

Back to the top